package com.jjt.biz.service.impl;

import com.jjt.biz.service.IApiAllService;
import com.jjt.biz.vo.AvgMonthVO;
import com.jjt.biz.vo.CurrYieldVO;
import com.jjt.biz.vo.EnergyTradeVO;
import com.jjt.biz.vo.ProdTradeVO;
import com.jjt.common.constant.CacheConstants;
import com.jjt.common.core.redis.RedisCache;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * 首页统计数据
 *
 * @author wukai
 * @date 2024/5/4 20:35
 */
@Service
@Slf4j
public class ApiAllServiceImpl implements IApiAllService {
    @Resource
    private RedisCache redisCache;

    /**
     * 获取当前库存数据
     *
     * @return 库存数据
     */
    @Override
    public Map<String, Object> stock() {
        return redisCache.getCacheObject(CacheConstants.VMS_STOCK);
    }

    /**
     * 获取本月平均值
     *
     * @return 结果
     */
    @Override
    public AvgMonthVO avgMonth() {
        AvgMonthVO vo = new AvgMonthVO();
        vo.mock();
        redisCache.setCacheObject(CacheConstants.AVG_MONTH, vo);
        return redisCache.getCacheObject(CacheConstants.AVG_MONTH);
    }

    /**
     * 获取生产情况
     *
     * @return 结果
     */
    @Override
    public CurrYieldVO currYield() {
        CurrYieldVO vo = new CurrYieldVO();
        vo.mock();
        redisCache.setCacheObject(CacheConstants.CURR_YIELD, vo);
        return redisCache.getCacheObject(CacheConstants.CURR_YIELD);
    }

    /**
     * 获取生产趋势
     *
     * @return 结果
     */
    @Override
    public List<ProdTradeVO> prodTrade() {
        redisCache.setCacheObject(CacheConstants.PROD_TRADE, mockProd());
        return redisCache.getCacheObject(CacheConstants.PROD_TRADE);
    }

    /**
     * 获取能耗趋势
     *
     * @return 结果
     */
    @Override
    public List<EnergyTradeVO> energyTrade() {
        redisCache.setCacheObject(CacheConstants.ENERGY_TRADE, mockEnergy());
        return redisCache.getCacheObject(CacheConstants.ENERGY_TRADE);
    }

    private List<ProdTradeVO> mockProd() {
        List<ProdTradeVO> list = new ArrayList<>();
        LocalDate end = LocalDate.now().minusDays(1);
        LocalDate start = end.minusDays(6);
        do {
            ProdTradeVO vo = new ProdTradeVO();
            vo.setDate(week(start));
            vo.setTips(start.toString());
            vo.mock();
            list.add(vo);
            start = start.plusDays(1);
        } while (!start.isAfter(end));
        return list;

    }

    private List<EnergyTradeVO> mockEnergy() {
        List<EnergyTradeVO> list = new ArrayList<>();
        LocalDate end = LocalDate.now().minusDays(1);
        LocalDate start = end.minusDays(30);
        do {
            EnergyTradeVO vo = new EnergyTradeVO();
            vo.setDate(start.getDayOfMonth() + "");
            vo.setTips(start.toString());
            vo.mock();
            list.add(vo);
            start = start.plusDays(1);
        } while (!start.isAfter(end));
        return list;

    }

    /**
     * 获取周几
     *
     * @param date
     * @return
     */
    private String week(LocalDate date) {
        String[] weeks = {"一", "二", "三", "四", "五", "六", "日"};
        return "周" + weeks[date.getDayOfWeek().getValue() - 1];
    }

    public static void main(String[] args) {
        int day = 7;
        LocalDate end = LocalDate.now().minusDays(1);
        LocalDate start = end.minusDays(day - 1);
        do {
            System.err.println(start + "\t" + start.getDayOfWeek().getValue());
            start = start.plusDays(1);
        } while (!start.isAfter(end));
    }

}
